import typing

import typing_extensions

_list = list

@typing.type_check_only
class AnthosObservabilityFeatureSpec(typing_extensions.TypedDict, total=False):
    defaultMembershipSpec: AnthosObservabilityMembershipSpec

@typing.type_check_only
class AnthosObservabilityMembershipSpec(typing_extensions.TypedDict, total=False):
    doNotOptimizeMetrics: bool
    enableStackdriverOnApplications: bool
    version: str

@typing.type_check_only
class AnthosVMMembershipSpec(typing_extensions.TypedDict, total=False):
    subfeaturesSpec: _list[AnthosVMSubFeatureSpec]

@typing.type_check_only
class AnthosVMMembershipState(typing_extensions.TypedDict, total=False):
    localControllerState: LocalControllerState
    subfeatureState: _list[AnthosVMSubFeatureState]

@typing.type_check_only
class AnthosVMSubFeatureSpec(typing_extensions.TypedDict, total=False):
    enabled: bool
    migrateSpec: MigrateSpec
    serviceMeshSpec: ServiceMeshSpec

@typing.type_check_only
class AnthosVMSubFeatureState(typing_extensions.TypedDict, total=False):
    description: str
    installationState: typing_extensions.Literal[
        "INSTALLATION_STATE_UNSPECIFIED",
        "INSTALLATION_STATE_NOT_INSTALLED",
        "INSTALLATION_STATE_INSTALLED",
        "INSTALLATION_STATE_FAILED",
    ]
    migrateState: MigrateState
    serviceMeshState: ServiceMeshState

@typing.type_check_only
class AppDevExperienceFeatureSpec(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class AppDevExperienceFeatureState(typing_extensions.TypedDict, total=False):
    networkingInstallSucceeded: Status

@typing.type_check_only
class ApplianceCluster(typing_extensions.TypedDict, total=False):
    resourceLink: str

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class Authority(typing_extensions.TypedDict, total=False):
    identityProvider: str
    issuer: str
    oidcJwks: str
    workloadIdentityPool: str

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CloudAuditLoggingFeatureSpec(typing_extensions.TypedDict, total=False):
    allowlistedServiceAccounts: _list[str]

@typing.type_check_only
class CloudBuildMembershipSpec(typing_extensions.TypedDict, total=False):
    securityPolicy: typing_extensions.Literal[
        "SECURITY_POLICY_UNSPECIFIED", "NON_PRIVILEGED", "PRIVILEGED"
    ]
    version: str

@typing.type_check_only
class CommonFeatureSpec(typing_extensions.TypedDict, total=False):
    anthosobservability: AnthosObservabilityFeatureSpec
    appdevexperience: AppDevExperienceFeatureSpec
    cloudauditlogging: CloudAuditLoggingFeatureSpec
    multiclusteringress: MultiClusterIngressFeatureSpec
    workloadcertificate: FeatureSpec

@typing.type_check_only
class CommonFeatureState(typing_extensions.TypedDict, total=False):
    appdevexperience: AppDevExperienceFeatureState
    servicemesh: ServiceMeshFeatureState
    state: FeatureState

@typing.type_check_only
class ConfigManagementBinauthzConfig(typing_extensions.TypedDict, total=False):
    enabled: bool

@typing.type_check_only
class ConfigManagementBinauthzState(typing_extensions.TypedDict, total=False):
    version: ConfigManagementBinauthzVersion
    webhook: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]

@typing.type_check_only
class ConfigManagementBinauthzVersion(typing_extensions.TypedDict, total=False):
    webhookVersion: str

@typing.type_check_only
class ConfigManagementConfigSync(typing_extensions.TypedDict, total=False):
    allowVerticalScale: bool
    enabled: bool
    git: ConfigManagementGitConfig
    oci: ConfigManagementOciConfig
    preventDrift: bool
    sourceFormat: str

@typing.type_check_only
class ConfigManagementConfigSyncDeploymentState(
    typing_extensions.TypedDict, total=False
):
    admissionWebhook: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]
    gitSync: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]
    importer: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]
    monitor: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]
    reconcilerManager: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]
    rootReconciler: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]
    syncer: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]

@typing.type_check_only
class ConfigManagementConfigSyncState(typing_extensions.TypedDict, total=False):
    deploymentState: ConfigManagementConfigSyncDeploymentState
    syncState: ConfigManagementSyncState
    version: ConfigManagementConfigSyncVersion

@typing.type_check_only
class ConfigManagementConfigSyncVersion(typing_extensions.TypedDict, total=False):
    admissionWebhook: str
    gitSync: str
    importer: str
    monitor: str
    reconcilerManager: str
    rootReconciler: str
    syncer: str

@typing.type_check_only
class ConfigManagementErrorResource(typing_extensions.TypedDict, total=False):
    resourceGvk: ConfigManagementGroupVersionKind
    resourceName: str
    resourceNamespace: str
    sourcePath: str

@typing.type_check_only
class ConfigManagementGatekeeperDeploymentState(
    typing_extensions.TypedDict, total=False
):
    gatekeeperAudit: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]
    gatekeeperControllerManagerState: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]
    gatekeeperMutation: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]

@typing.type_check_only
class ConfigManagementGitConfig(typing_extensions.TypedDict, total=False):
    gcpServiceAccountEmail: str
    httpsProxy: str
    policyDir: str
    secretType: str
    syncBranch: str
    syncRepo: str
    syncRev: str
    syncWaitSecs: str

@typing.type_check_only
class ConfigManagementGroupVersionKind(typing_extensions.TypedDict, total=False):
    group: str
    kind: str
    version: str

@typing.type_check_only
class ConfigManagementHierarchyControllerConfig(
    typing_extensions.TypedDict, total=False
):
    enableHierarchicalResourceQuota: bool
    enablePodTreeLabels: bool
    enabled: bool

@typing.type_check_only
class ConfigManagementHierarchyControllerDeploymentState(
    typing_extensions.TypedDict, total=False
):
    extension: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]
    hnc: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]

@typing.type_check_only
class ConfigManagementHierarchyControllerState(
    typing_extensions.TypedDict, total=False
):
    state: ConfigManagementHierarchyControllerDeploymentState
    version: ConfigManagementHierarchyControllerVersion

@typing.type_check_only
class ConfigManagementHierarchyControllerVersion(
    typing_extensions.TypedDict, total=False
):
    extension: str
    hnc: str

@typing.type_check_only
class ConfigManagementInstallError(typing_extensions.TypedDict, total=False):
    errorMessage: str

@typing.type_check_only
class ConfigManagementMembershipSpec(typing_extensions.TypedDict, total=False):
    binauthz: ConfigManagementBinauthzConfig
    configSync: ConfigManagementConfigSync
    hierarchyController: ConfigManagementHierarchyControllerConfig
    policyController: ConfigManagementPolicyController
    version: str

@typing.type_check_only
class ConfigManagementMembershipState(typing_extensions.TypedDict, total=False):
    binauthzState: ConfigManagementBinauthzState
    clusterName: str
    configSyncState: ConfigManagementConfigSyncState
    hierarchyControllerState: ConfigManagementHierarchyControllerState
    membershipSpec: ConfigManagementMembershipSpec
    operatorState: ConfigManagementOperatorState
    policyControllerState: ConfigManagementPolicyControllerState

@typing.type_check_only
class ConfigManagementOciConfig(typing_extensions.TypedDict, total=False):
    gcpServiceAccountEmail: str
    policyDir: str
    secretType: str
    syncRepo: str
    syncWaitSecs: str

@typing.type_check_only
class ConfigManagementOperatorState(typing_extensions.TypedDict, total=False):
    deploymentState: typing_extensions.Literal[
        "DEPLOYMENT_STATE_UNSPECIFIED", "NOT_INSTALLED", "INSTALLED", "ERROR"
    ]
    errors: _list[ConfigManagementInstallError]
    version: str

@typing.type_check_only
class ConfigManagementPolicyController(typing_extensions.TypedDict, total=False):
    auditIntervalSeconds: str
    enabled: bool
    exemptableNamespaces: _list[str]
    logDeniesEnabled: bool
    monitoring: ConfigManagementPolicyControllerMonitoring
    mutationEnabled: bool
    referentialRulesEnabled: bool
    templateLibraryInstalled: bool

@typing.type_check_only
class ConfigManagementPolicyControllerMonitoring(
    typing_extensions.TypedDict, total=False
):
    backends: _list[str]

@typing.type_check_only
class ConfigManagementPolicyControllerState(typing_extensions.TypedDict, total=False):
    deploymentState: ConfigManagementGatekeeperDeploymentState
    version: ConfigManagementPolicyControllerVersion

@typing.type_check_only
class ConfigManagementPolicyControllerVersion(typing_extensions.TypedDict, total=False):
    version: str

@typing.type_check_only
class ConfigManagementSyncError(typing_extensions.TypedDict, total=False):
    code: str
    errorMessage: str
    errorResources: _list[ConfigManagementErrorResource]

@typing.type_check_only
class ConfigManagementSyncState(typing_extensions.TypedDict, total=False):
    code: typing_extensions.Literal[
        "SYNC_CODE_UNSPECIFIED",
        "SYNCED",
        "PENDING",
        "ERROR",
        "NOT_CONFIGURED",
        "NOT_INSTALLED",
        "UNAUTHORIZED",
        "UNREACHABLE",
    ]
    errors: _list[ConfigManagementSyncError]
    importToken: str
    lastSync: str
    lastSyncTime: str
    sourceToken: str
    syncToken: str

@typing.type_check_only
class ConnectAgentResource(typing_extensions.TypedDict, total=False):
    manifest: str
    type: TypeMeta

@typing.type_check_only
class EdgeCluster(typing_extensions.TypedDict, total=False):
    resourceLink: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class Feature(typing_extensions.TypedDict, total=False):
    createTime: str
    deleteTime: str
    labels: dict[str, typing.Any]
    membershipSpecs: dict[str, typing.Any]
    membershipStates: dict[str, typing.Any]
    name: str
    resourceState: FeatureResourceState
    spec: CommonFeatureSpec
    state: CommonFeatureState
    updateTime: str

@typing.type_check_only
class FeatureResourceState(typing_extensions.TypedDict, total=False):
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "ENABLING",
        "ACTIVE",
        "DISABLING",
        "UPDATING",
        "SERVICE_UPDATING",
    ]

@typing.type_check_only
class FeatureSpec(typing_extensions.TypedDict, total=False):
    defaultConfig: MembershipSpec
    provisionGoogleCa: typing_extensions.Literal[
        "GOOGLE_CA_PROVISIONING_UNSPECIFIED", "DISABLED", "ENABLED"
    ]

@typing.type_check_only
class FeatureState(typing_extensions.TypedDict, total=False):
    code: typing_extensions.Literal["CODE_UNSPECIFIED", "OK", "WARNING", "ERROR"]
    description: str
    updateTime: str

@typing.type_check_only
class Fleet(typing_extensions.TypedDict, total=False):
    createTime: str
    deleteTime: str
    displayName: str
    name: str
    state: FleetLifecycleState
    uid: str
    updateTime: str

@typing.type_check_only
class FleetLifecycleState(typing_extensions.TypedDict, total=False):
    code: typing_extensions.Literal[
        "CODE_UNSPECIFIED", "CREATING", "READY", "DELETING", "UPDATING"
    ]

@typing.type_check_only
class GenerateConnectManifestResponse(typing_extensions.TypedDict, total=False):
    manifest: _list[ConnectAgentResource]

@typing.type_check_only
class GkeCluster(typing_extensions.TypedDict, total=False):
    clusterMissing: bool
    resourceLink: str

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class IdentityServiceAuthMethod(typing_extensions.TypedDict, total=False):
    googleConfig: IdentityServiceGoogleConfig
    name: str
    oidcConfig: IdentityServiceOidcConfig
    proxy: str

@typing.type_check_only
class IdentityServiceGoogleConfig(typing_extensions.TypedDict, total=False):
    disable: bool

@typing.type_check_only
class IdentityServiceMembershipSpec(typing_extensions.TypedDict, total=False):
    authMethods: _list[IdentityServiceAuthMethod]

@typing.type_check_only
class IdentityServiceMembershipState(typing_extensions.TypedDict, total=False):
    failureReason: str
    installedVersion: str
    memberConfig: IdentityServiceMembershipSpec
    state: typing_extensions.Literal["DEPLOYMENT_STATE_UNSPECIFIED", "OK", "ERROR"]

@typing.type_check_only
class IdentityServiceOidcConfig(typing_extensions.TypedDict, total=False):
    certificateAuthorityData: str
    clientId: str
    clientSecret: str
    deployCloudConsoleProxy: bool
    enableAccessToken: bool
    encryptedClientSecret: str
    extraParams: str
    groupPrefix: str
    groupsClaim: str
    issuerUri: str
    kubectlRedirectUri: str
    scopes: str
    userClaim: str
    userPrefix: str

@typing.type_check_only
class KubernetesMetadata(typing_extensions.TypedDict, total=False):
    kubernetesApiServerVersion: str
    memoryMb: int
    nodeCount: int
    nodeProviderId: str
    updateTime: str
    vcpuCount: int

@typing.type_check_only
class KubernetesResource(typing_extensions.TypedDict, total=False):
    connectResources: _list[ResourceManifest]
    membershipCrManifest: str
    membershipResources: _list[ResourceManifest]
    resourceOptions: ResourceOptions

@typing.type_check_only
class ListAdminClusterMembershipsResponse(typing_extensions.TypedDict, total=False):
    adminClusterMemberships: _list[Membership]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListFeaturesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    resources: _list[Feature]

@typing.type_check_only
class ListFleetsResponse(typing_extensions.TypedDict, total=False):
    fleets: _list[Fleet]
    nextPageToken: str

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListMembershipsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    resources: _list[Membership]
    unreachable: _list[str]

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class LocalControllerState(typing_extensions.TypedDict, total=False):
    description: str
    installationState: typing_extensions.Literal[
        "INSTALLATION_STATE_UNSPECIFIED",
        "INSTALLATION_STATE_NOT_INSTALLED",
        "INSTALLATION_STATE_INSTALLED",
        "INSTALLATION_STATE_FAILED",
    ]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class Membership(typing_extensions.TypedDict, total=False):
    authority: Authority
    createTime: str
    deleteTime: str
    description: str
    endpoint: MembershipEndpoint
    externalId: str
    labels: dict[str, typing.Any]
    lastConnectionTime: str
    name: str
    state: MembershipState
    uniqueId: str
    updateTime: str

@typing.type_check_only
class MembershipEndpoint(typing_extensions.TypedDict, total=False):
    applianceCluster: ApplianceCluster
    edgeCluster: EdgeCluster
    gkeCluster: GkeCluster
    kubernetesMetadata: KubernetesMetadata
    kubernetesResource: KubernetesResource
    multiCloudCluster: MultiCloudCluster
    onPremCluster: OnPremCluster

@typing.type_check_only
class MembershipFeatureSpec(typing_extensions.TypedDict, total=False):
    anthosobservability: AnthosObservabilityMembershipSpec
    anthosvm: AnthosVMMembershipSpec
    cloudbuild: CloudBuildMembershipSpec
    configmanagement: ConfigManagementMembershipSpec
    identityservice: IdentityServiceMembershipSpec
    mesh: ServiceMeshMembershipSpec
    policycontroller: PolicyControllerMembershipSpec
    workloadcertificate: MembershipSpec

@typing.type_check_only
class MembershipFeatureState(typing_extensions.TypedDict, total=False):
    anthosvm: AnthosVMMembershipState
    appdevexperience: AppDevExperienceFeatureState
    configmanagement: ConfigManagementMembershipState
    identityservice: IdentityServiceMembershipState
    metering: MeteringMembershipState
    policycontroller: PolicyControllerMembershipState
    servicemesh: ServiceMeshMembershipState
    state: FeatureState

@typing.type_check_only
class MembershipSpec(typing_extensions.TypedDict, total=False):
    certificateManagement: typing_extensions.Literal[
        "CERTIFICATE_MANAGEMENT_UNSPECIFIED", "DISABLED", "ENABLED"
    ]

@typing.type_check_only
class MembershipState(typing_extensions.TypedDict, total=False):
    code: typing_extensions.Literal[
        "CODE_UNSPECIFIED",
        "CREATING",
        "READY",
        "DELETING",
        "UPDATING",
        "SERVICE_UPDATING",
    ]

@typing.type_check_only
class MeteringMembershipState(typing_extensions.TypedDict, total=False):
    lastMeasurementTime: str
    preciseLastMeasuredClusterVcpuCapacity: float

@typing.type_check_only
class MigrateSpec(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class MigrateState(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class MultiCloudCluster(typing_extensions.TypedDict, total=False):
    clusterMissing: bool
    resourceLink: str

@typing.type_check_only
class MultiClusterIngressFeatureSpec(typing_extensions.TypedDict, total=False):
    billing: typing_extensions.Literal[
        "BILLING_UNSPECIFIED", "PAY_AS_YOU_GO", "ANTHOS_LICENSE"
    ]
    configMembership: str

@typing.type_check_only
class OnPremCluster(typing_extensions.TypedDict, total=False):
    adminCluster: bool
    clusterMissing: bool
    clusterType: typing_extensions.Literal[
        "CLUSTERTYPE_UNSPECIFIED", "BOOTSTRAP", "HYBRID", "STANDALONE", "USER"
    ]
    resourceLink: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: GoogleRpcStatus
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    cancelRequested: bool
    createTime: str
    endTime: str
    statusDetail: str
    target: str
    verb: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class PolicyControllerHubConfig(typing_extensions.TypedDict, total=False):
    auditIntervalSeconds: str
    exemptableNamespaces: _list[str]
    installSpec: typing_extensions.Literal[
        "INSTALL_SPEC_UNSPECIFIED",
        "INSTALL_SPEC_NOT_INSTALLED",
        "INSTALL_SPEC_ENABLED",
        "INSTALL_SPEC_SUSPENDED",
    ]
    logDeniesEnabled: bool
    monitoring: PolicyControllerMonitoringConfig
    mutationEnabled: bool
    referentialRulesEnabled: bool
    templateLibraryConfig: PolicyControllerTemplateLibraryConfig

@typing.type_check_only
class PolicyControllerMembershipSpec(typing_extensions.TypedDict, total=False):
    policyControllerHubConfig: PolicyControllerHubConfig
    version: str

@typing.type_check_only
class PolicyControllerMembershipState(typing_extensions.TypedDict, total=False):
    clusterName: str
    componentStates: dict[str, typing.Any]
    state: typing_extensions.Literal[
        "LIFECYCLE_STATE_UNSPECIFIED",
        "NOT_INSTALLED",
        "INSTALLING",
        "ACTIVE",
        "UPDATING",
        "DECOMISSIONING",
        "CLUSTER_ERROR",
        "HUB_ERROR",
        "SUSPENDED",
    ]

@typing.type_check_only
class PolicyControllerMonitoringConfig(typing_extensions.TypedDict, total=False):
    backends: _list[str]

@typing.type_check_only
class PolicyControllerOnClusterState(typing_extensions.TypedDict, total=False):
    details: str
    state: typing_extensions.Literal[
        "LIFECYCLE_STATE_UNSPECIFIED",
        "NOT_INSTALLED",
        "INSTALLING",
        "ACTIVE",
        "UPDATING",
        "DECOMISSIONING",
        "CLUSTER_ERROR",
        "HUB_ERROR",
        "SUSPENDED",
    ]

@typing.type_check_only
class PolicyControllerTemplateLibraryConfig(typing_extensions.TypedDict, total=False):
    included: bool

@typing.type_check_only
class ResourceManifest(typing_extensions.TypedDict, total=False):
    clusterScoped: bool
    manifest: str

@typing.type_check_only
class ResourceOptions(typing_extensions.TypedDict, total=False):
    connectVersion: str
    k8sVersion: str
    v1beta1Crd: bool

@typing.type_check_only
class ServiceMeshAnalysisMessage(typing_extensions.TypedDict, total=False):
    args: dict[str, typing.Any]
    description: str
    messageBase: ServiceMeshAnalysisMessageBase
    resourcePaths: _list[str]

@typing.type_check_only
class ServiceMeshAnalysisMessageBase(typing_extensions.TypedDict, total=False):
    documentationUrl: str
    level: typing_extensions.Literal["LEVEL_UNSPECIFIED", "ERROR", "WARNING", "INFO"]
    type: ServiceMeshType

@typing.type_check_only
class ServiceMeshControlPlaneManagement(typing_extensions.TypedDict, total=False):
    details: _list[ServiceMeshStatusDetails]
    state: typing_extensions.Literal[
        "LIFECYCLE_STATE_UNSPECIFIED",
        "DISABLED",
        "FAILED_PRECONDITION",
        "PROVISIONING",
        "ACTIVE",
        "STALLED",
        "NEEDS_ATTENTION",
        "DEGRADED",
    ]

@typing.type_check_only
class ServiceMeshDataPlaneManagement(typing_extensions.TypedDict, total=False):
    details: _list[ServiceMeshStatusDetails]
    state: typing_extensions.Literal[
        "LIFECYCLE_STATE_UNSPECIFIED",
        "DISABLED",
        "FAILED_PRECONDITION",
        "PROVISIONING",
        "ACTIVE",
        "STALLED",
        "NEEDS_ATTENTION",
        "DEGRADED",
    ]

@typing.type_check_only
class ServiceMeshFeatureState(typing_extensions.TypedDict, total=False):
    analysisMessages: _list[ServiceMeshAnalysisMessage]

@typing.type_check_only
class ServiceMeshMembershipSpec(typing_extensions.TypedDict, total=False):
    controlPlane: typing_extensions.Literal[
        "CONTROL_PLANE_MANAGEMENT_UNSPECIFIED", "AUTOMATIC", "MANUAL"
    ]
    defaultChannel: typing_extensions.Literal[
        "CHANNEL_UNSPECIFIED", "RAPID", "REGULAR", "STABLE"
    ]
    management: typing_extensions.Literal[
        "MANAGEMENT_UNSPECIFIED", "MANAGEMENT_AUTOMATIC", "MANAGEMENT_MANUAL"
    ]

@typing.type_check_only
class ServiceMeshMembershipState(typing_extensions.TypedDict, total=False):
    analysisMessages: _list[ServiceMeshAnalysisMessage]
    configApiVersion: str
    controlPlaneManagement: ServiceMeshControlPlaneManagement
    dataPlaneManagement: ServiceMeshDataPlaneManagement

@typing.type_check_only
class ServiceMeshSpec(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ServiceMeshState(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ServiceMeshStatusDetails(typing_extensions.TypedDict, total=False):
    code: str
    details: str

@typing.type_check_only
class ServiceMeshType(typing_extensions.TypedDict, total=False):
    code: str
    displayName: str

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: typing_extensions.Literal["CODE_UNSPECIFIED", "OK", "FAILED", "UNKNOWN"]
    description: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TypeMeta(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str

@typing.type_check_only
class ValidateCreateMembershipRequest(typing_extensions.TypedDict, total=False):
    membership: Membership
    membershipId: str

@typing.type_check_only
class ValidateCreateMembershipResponse(typing_extensions.TypedDict, total=False):
    validationResults: _list[ValidationResult]

@typing.type_check_only
class ValidationResult(typing_extensions.TypedDict, total=False):
    result: str
    success: bool
    validator: typing_extensions.Literal[
        "VALIDATOR_TYPE_UNSPECIFIED", "MEMBERSHIP_ID", "CROSS_PROJECT_PERMISSION"
    ]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ModelOperationMetadata(typing_extensions.TypedDict, total=False):
    basicOperationStatus: typing_extensions.Literal[
        "BASIC_OPERATION_STATUS_UNSPECIFIED",
        "BASIC_OPERATION_STATUS_UPLOADING",
        "BASIC_OPERATION_STATUS_VERIFYING",
    ]
    name: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class MyBusinessBusinessInformationResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccountsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                parent: str,
                body: Location = ...,
                requestId: str = ...,
                validateOnly: bool = ...,
                **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                readMask: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...

        def locations(self) -> LocationsResource: ...

    @typing.type_check_only
    class AttributesResource(googleapiclient.discovery.Resource):
        def list(
            self,
            *,
            categoryName: str = ...,
            languageCode: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            parent: str = ...,
            regionCode: str = ...,
            showAll: bool = ...,
            **kwargs: typing.Any
        ) -> ListAttributeMetadataResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListAttributeMetadataResponseHttpRequest,
            previous_response: ListAttributeMetadataResponse,
        ) -> ListAttributeMetadataResponseHttpRequest | None: ...

    @typing.type_check_only
    class CategoriesResource(googleapiclient.discovery.Resource):
        def batchGet(
            self,
            *,
            languageCode: str = ...,
            names: str | _list[str] = ...,
            regionCode: str = ...,
            view: typing_extensions.Literal[
                "CATEGORY_VIEW_UNSPECIFIED", "BASIC", "FULL"
            ] = ...,
            **kwargs: typing.Any
        ) -> BatchGetCategoriesResponseHttpRequest: ...
        def list(
            self,
            *,
            filter: str = ...,
            languageCode: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            regionCode: str = ...,
            view: typing_extensions.Literal[
                "CATEGORY_VIEW_UNSPECIFIED", "BASIC", "FULL"
            ] = ...,
            **kwargs: typing.Any
        ) -> ListCategoriesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListCategoriesResponseHttpRequest,
            previous_response: ListCategoriesResponse,
        ) -> ListCategoriesResponseHttpRequest | None: ...

    @typing.type_check_only
    class ChainsResource(googleapiclient.discovery.Resource):
        def get(self, *, name: str, **kwargs: typing.Any) -> ChainHttpRequest: ...
        def search(
            self, *, chainName: str = ..., pageSize: int = ..., **kwargs: typing.Any
        ) -> SearchChainsResponseHttpRequest: ...

    @typing.type_check_only
    class GoogleLocationsResource(googleapiclient.discovery.Resource):
        def search(
            self, *, body: SearchGoogleLocationsRequest = ..., **kwargs: typing.Any
        ) -> SearchGoogleLocationsResponseHttpRequest: ...

    @typing.type_check_only
    class LocationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AttributesResource(googleapiclient.discovery.Resource):
            def getGoogleUpdated(
                self, *, name: str, **kwargs: typing.Any
            ) -> AttributesHttpRequest: ...

        def associate(
            self,
            *,
            name: str,
            body: AssociateLocationRequest = ...,
            **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def clearLocationAssociation(
            self,
            *,
            name: str,
            body: ClearLocationAssociationRequest = ...,
            **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...
        def delete(self, *, name: str, **kwargs: typing.Any) -> EmptyHttpRequest: ...
        def get(
            self, *, name: str, readMask: str = ..., **kwargs: typing.Any
        ) -> LocationHttpRequest: ...
        def getAttributes(
            self, *, name: str, **kwargs: typing.Any
        ) -> AttributesHttpRequest: ...
        def getGoogleUpdated(
            self, *, name: str, readMask: str = ..., **kwargs: typing.Any
        ) -> GoogleUpdatedLocationHttpRequest: ...
        def patch(
            self,
            *,
            name: str,
            body: Location = ...,
            updateMask: str = ...,
            validateOnly: bool = ...,
            **kwargs: typing.Any
        ) -> LocationHttpRequest: ...
        def updateAttributes(
            self,
            *,
            name: str,
            body: Attributes = ...,
            attributeMask: str = ...,
            **kwargs: typing.Any
        ) -> AttributesHttpRequest: ...
        def attributes(self) -> AttributesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accounts(self) -> AccountsResource: ...
    def attributes(self) -> AttributesResource: ...
    def categories(self) -> CategoriesResource: ...
    def chains(self) -> ChainsResource: ...
    def googleLocations(self) -> GoogleLocationsResource: ...
    def locations(self) -> LocationsResource: ...

@typing.type_check_only
class AttributesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Attributes: ...

@typing.type_check_only
class BatchGetCategoriesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchGetCategoriesResponse: ...

@typing.type_check_only
class ChainHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Chain: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GoogleUpdatedLocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleUpdatedLocation: ...

@typing.type_check_only
class ListAttributeMetadataResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAttributeMetadataResponse: ...

@typing.type_check_only
class ListCategoriesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCategoriesResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class SearchChainsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchChainsResponse: ...

@typing.type_check_only
class SearchGoogleLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchGoogleLocationsResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GdataBlobstore2Info(typing_extensions.TypedDict, total=False):
    blobGeneration: str
    blobId: str
    downloadReadHandle: str
    readToken: str
    uploadMetadataContainer: str

@typing.type_check_only
class GdataCompositeMedia(typing_extensions.TypedDict, total=False):
    blobRef: str
    blobstore2Info: GdataBlobstore2Info
    cosmoBinaryReference: str
    crc32cHash: int
    inline: str
    length: str
    md5Hash: str
    objectId: GdataObjectId
    path: str
    referenceType: typing_extensions.Literal[
        "PATH", "BLOB_REF", "INLINE", "BIGSTORE_REF", "COSMO_BINARY_REFERENCE"
    ]
    sha1Hash: str

@typing.type_check_only
class GdataContentTypeInfo(typing_extensions.TypedDict, total=False):
    bestGuess: str
    fromBytes: str
    fromFileName: str
    fromHeader: str
    fromUrlPath: str

@typing.type_check_only
class GdataDiffChecksumsResponse(typing_extensions.TypedDict, total=False):
    checksumsLocation: GdataCompositeMedia
    chunkSizeBytes: str
    objectLocation: GdataCompositeMedia
    objectSizeBytes: str
    objectVersion: str

@typing.type_check_only
class GdataDiffDownloadResponse(typing_extensions.TypedDict, total=False):
    objectLocation: GdataCompositeMedia

@typing.type_check_only
class GdataDiffUploadRequest(typing_extensions.TypedDict, total=False):
    checksumsInfo: GdataCompositeMedia
    objectInfo: GdataCompositeMedia
    objectVersion: str

@typing.type_check_only
class GdataDiffUploadResponse(typing_extensions.TypedDict, total=False):
    objectVersion: str
    originalObject: GdataCompositeMedia

@typing.type_check_only
class GdataDiffVersionResponse(typing_extensions.TypedDict, total=False):
    objectSizeBytes: str
    objectVersion: str

@typing.type_check_only
class GdataDownloadParameters(typing_extensions.TypedDict, total=False):
    allowGzipCompression: bool
    ignoreRange: bool

@typing.type_check_only
class GdataMedia(typing_extensions.TypedDict, total=False):
    algorithm: str
    bigstoreObjectRef: str
    blobRef: str
    blobstore2Info: GdataBlobstore2Info
    compositeMedia: _list[GdataCompositeMedia]
    contentType: str
    contentTypeInfo: GdataContentTypeInfo
    cosmoBinaryReference: str
    crc32cHash: int
    diffChecksumsResponse: GdataDiffChecksumsResponse
    diffDownloadResponse: GdataDiffDownloadResponse
    diffUploadRequest: GdataDiffUploadRequest
    diffUploadResponse: GdataDiffUploadResponse
    diffVersionResponse: GdataDiffVersionResponse
    downloadParameters: GdataDownloadParameters
    filename: str
    hash: str
    hashVerified: bool
    inline: str
    isPotentialRetry: bool
    length: str
    md5Hash: str
    mediaId: str
    objectId: GdataObjectId
    path: str
    referenceType: typing_extensions.Literal[
        "PATH",
        "BLOB_REF",
        "INLINE",
        "GET_MEDIA",
        "COMPOSITE_MEDIA",
        "BIGSTORE_REF",
        "DIFF_VERSION_RESPONSE",
        "DIFF_CHECKSUMS_RESPONSE",
        "DIFF_DOWNLOAD_RESPONSE",
        "DIFF_UPLOAD_REQUEST",
        "DIFF_UPLOAD_RESPONSE",
        "COSMO_BINARY_REFERENCE",
        "ARBITRARY_BYTES",
    ]
    sha1Hash: str
    sha256Hash: str
    timestamp: str
    token: str

@typing.type_check_only
class GdataObjectId(typing_extensions.TypedDict, total=False):
    bucketName: str
    generation: str
    objectName: str

@typing.type_check_only
class Job(typing_extensions.TypedDict, total=False):
    createTime: str
    expireTime: str
    id: str
    name: str
    reportTypeId: str
    systemManaged: bool

@typing.type_check_only
class ListJobsResponse(typing_extensions.TypedDict, total=False):
    jobs: _list[Job]
    nextPageToken: str

@typing.type_check_only
class ListReportTypesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    reportTypes: _list[ReportType]

@typing.type_check_only
class ListReportsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    reports: _list[Report]

@typing.type_check_only
class Report(typing_extensions.TypedDict, total=False):
    createTime: str
    downloadUrl: str
    endTime: str
    id: str
    jobExpireTime: str
    jobId: str
    startTime: str

@typing.type_check_only
class ReportType(typing_extensions.TypedDict, total=False):
    deprecateTime: str
    id: str
    name: str
    systemManaged: bool



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class HomeGraphServiceResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AgentUsersResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, agentUserId: str, requestId: str = ..., **kwargs: typing.Any
        ) -> EmptyHttpRequest: ...

    @typing.type_check_only
    class DevicesResource(googleapiclient.discovery.Resource):
        def query(
            self, *, body: QueryRequest = ..., **kwargs: typing.Any
        ) -> QueryResponseHttpRequest: ...
        def reportStateAndNotification(
            self, *, body: ReportStateAndNotificationRequest = ..., **kwargs: typing.Any
        ) -> ReportStateAndNotificationResponseHttpRequest: ...
        def requestSync(
            self, *, body: RequestSyncDevicesRequest = ..., **kwargs: typing.Any
        ) -> RequestSyncDevicesResponseHttpRequest: ...
        def sync(
            self, *, body: SyncRequest = ..., **kwargs: typing.Any
        ) -> SyncResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def agentUsers(self) -> AgentUsersResource: ...
    def devices(self) -> DevicesResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class QueryResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> QueryResponse: ...

@typing.type_check_only
class ReportStateAndNotificationResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReportStateAndNotificationResponse: ...

@typing.type_check_only
class RequestSyncDevicesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RequestSyncDevicesResponse: ...

@typing.type_check_only
class SyncResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SyncResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class EssentialcontactsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class FoldersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ContactsResource(googleapiclient.discovery.Resource):
            def compute(
                self,
                *,
                parent: str,
                notificationCategories: typing_extensions.Literal[
                    "NOTIFICATION_CATEGORY_UNSPECIFIED",
                    "ALL",
                    "SUSPENSION",
                    "SECURITY",
                    "TECHNICAL",
                    "BILLING",
                    "LEGAL",
                    "PRODUCT_UPDATES",
                    "TECHNICAL_INCIDENTS",
                ]
                | _list[
                    typing_extensions.Literal[
                        "NOTIFICATION_CATEGORY_UNSPECIFIED",
                        "ALL",
                        "SUSPENSION",
                        "SECURITY",
                        "TECHNICAL",
                        "BILLING",
                        "LEGAL",
                        "PRODUCT_UPDATES",
                        "TECHNICAL_INCIDENTS",
                    ]
                ] = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ComputeContactsResponseHttpRequest: ...
            def compute_next(
                self,
                previous_request: GoogleCloudEssentialcontactsV1ComputeContactsResponseHttpRequest,
                previous_response: GoogleCloudEssentialcontactsV1ComputeContactsResponse,
            ) -> GoogleCloudEssentialcontactsV1ComputeContactsResponseHttpRequest | None: ...
            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudEssentialcontactsV1Contact = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ContactHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ContactHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ListContactsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudEssentialcontactsV1ListContactsResponseHttpRequest,
                previous_response: GoogleCloudEssentialcontactsV1ListContactsResponse,
            ) -> GoogleCloudEssentialcontactsV1ListContactsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudEssentialcontactsV1Contact = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ContactHttpRequest: ...
            def sendTestMessage(
                self,
                *,
                resource: str,
                body: GoogleCloudEssentialcontactsV1SendTestMessageRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...

        def contacts(self) -> ContactsResource: ...

    @typing.type_check_only
    class OrganizationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ContactsResource(googleapiclient.discovery.Resource):
            def compute(
                self,
                *,
                parent: str,
                notificationCategories: typing_extensions.Literal[
                    "NOTIFICATION_CATEGORY_UNSPECIFIED",
                    "ALL",
                    "SUSPENSION",
                    "SECURITY",
                    "TECHNICAL",
                    "BILLING",
                    "LEGAL",
                    "PRODUCT_UPDATES",
                    "TECHNICAL_INCIDENTS",
                ]
                | _list[
                    typing_extensions.Literal[
                        "NOTIFICATION_CATEGORY_UNSPECIFIED",
                        "ALL",
                        "SUSPENSION",
                        "SECURITY",
                        "TECHNICAL",
                        "BILLING",
                        "LEGAL",
                        "PRODUCT_UPDATES",
                        "TECHNICAL_INCIDENTS",
                    ]
                ] = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ComputeContactsResponseHttpRequest: ...
            def compute_next(
                self,
                previous_request: GoogleCloudEssentialcontactsV1ComputeContactsResponseHttpRequest,
                previous_response: GoogleCloudEssentialcontactsV1ComputeContactsResponse,
            ) -> GoogleCloudEssentialcontactsV1ComputeContactsResponseHttpRequest | None: ...
            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudEssentialcontactsV1Contact = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ContactHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ContactHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ListContactsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudEssentialcontactsV1ListContactsResponseHttpRequest,
                previous_response: GoogleCloudEssentialcontactsV1ListContactsResponse,
            ) -> GoogleCloudEssentialcontactsV1ListContactsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudEssentialcontactsV1Contact = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ContactHttpRequest: ...
            def sendTestMessage(
                self,
                *,
                resource: str,
                body: GoogleCloudEssentialcontactsV1SendTestMessageRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...

        def contacts(self) -> ContactsResource: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ContactsResource(googleapiclient.discovery.Resource):
            def compute(
                self,
                *,
                parent: str,
                notificationCategories: typing_extensions.Literal[
                    "NOTIFICATION_CATEGORY_UNSPECIFIED",
                    "ALL",
                    "SUSPENSION",
                    "SECURITY",
                    "TECHNICAL",
                    "BILLING",
                    "LEGAL",
                    "PRODUCT_UPDATES",
                    "TECHNICAL_INCIDENTS",
                ]
                | _list[
                    typing_extensions.Literal[
                        "NOTIFICATION_CATEGORY_UNSPECIFIED",
                        "ALL",
                        "SUSPENSION",
                        "SECURITY",
                        "TECHNICAL",
                        "BILLING",
                        "LEGAL",
                        "PRODUCT_UPDATES",
                        "TECHNICAL_INCIDENTS",
                    ]
                ] = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ComputeContactsResponseHttpRequest: ...
            def compute_next(
                self,
                previous_request: GoogleCloudEssentialcontactsV1ComputeContactsResponseHttpRequest,
                previous_response: GoogleCloudEssentialcontactsV1ComputeContactsResponse,
            ) -> GoogleCloudEssentialcontactsV1ComputeContactsResponseHttpRequest | None: ...
            def create(
                self,
                *,
                parent: str,
                body: GoogleCloudEssentialcontactsV1Contact = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ContactHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ContactHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ListContactsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: GoogleCloudEssentialcontactsV1ListContactsResponseHttpRequest,
                previous_response: GoogleCloudEssentialcontactsV1ListContactsResponse,
            ) -> GoogleCloudEssentialcontactsV1ListContactsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleCloudEssentialcontactsV1Contact = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleCloudEssentialcontactsV1ContactHttpRequest: ...
            def sendTestMessage(
                self,
                *,
                resource: str,
                body: GoogleCloudEssentialcontactsV1SendTestMessageRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleProtobufEmptyHttpRequest: ...

        def contacts(self) -> ContactsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def folders(self) -> FoldersResource: ...
    def organizations(self) -> OrganizationsResource: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleCloudEssentialcontactsV1ComputeContactsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudEssentialcontactsV1ComputeContactsResponse: ...

@typing.type_check_only
class GoogleCloudEssentialcontactsV1ContactHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudEssentialcontactsV1Contact: ...

@typing.type_check_only
class GoogleCloudEssentialcontactsV1ListContactsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleCloudEssentialcontactsV1ListContactsResponse: ...

@typing.type_check_only
class GoogleProtobufEmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleProtobufEmpty: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class EventarcResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    name: str,
                    body: CancelOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListOperationsResponseHttpRequest,
                    previous_response: ListOperationsResponse,
                ) -> ListOperationsResponseHttpRequest | None: ...

            @typing.type_check_only
            class TriggersResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: Trigger = ...,
                    triggerId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self,
                    *,
                    name: str,
                    allowMissing: bool = ...,
                    etag: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> TriggerHttpRequest: ...
                def getIamPolicy(
                    self,
                    *,
                    resource: str,
                    options_requestedPolicyVersion: int = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListTriggersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListTriggersResponseHttpRequest,
                    previous_response: ListTriggersResponse,
                ) -> ListTriggersResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Trigger = ...,
                    allowMissing: bool = ...,
                    updateMask: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def setIamPolicy(
                    self,
                    *,
                    resource: str,
                    body: SetIamPolicyRequest = ...,
                    **kwargs: typing.Any
                ) -> PolicyHttpRequest: ...
                def testIamPermissions(
                    self,
                    *,
                    resource: str,
                    body: TestIamPermissionsRequest = ...,
                    **kwargs: typing.Any
                ) -> TestIamPermissionsResponseHttpRequest: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...
            def operations(self) -> OperationsResource: ...
            def triggers(self) -> TriggersResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListTriggersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListTriggersResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...

@typing.type_check_only
class TriggerHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Trigger: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class PlaydeveloperreportingResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AnomaliesResource(googleapiclient.discovery.Resource):
        def list(
            self,
            *,
            parent: str,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> GooglePlayDeveloperReportingV1beta1ListAnomaliesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: GooglePlayDeveloperReportingV1beta1ListAnomaliesResponseHttpRequest,
            previous_response: GooglePlayDeveloperReportingV1beta1ListAnomaliesResponse,
        ) -> GooglePlayDeveloperReportingV1beta1ListAnomaliesResponseHttpRequest | None: ...

    @typing.type_check_only
    class VitalsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AnrrateResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1beta1AnrRateMetricSetHttpRequest: ...
            def query(
                self,
                *,
                name: str,
                body: GooglePlayDeveloperReportingV1beta1QueryAnrRateMetricSetRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1beta1QueryAnrRateMetricSetResponseHttpRequest: ...
            def query_next(
                self,
                previous_request: GooglePlayDeveloperReportingV1beta1QueryAnrRateMetricSetResponseHttpRequest,
                previous_response: GooglePlayDeveloperReportingV1beta1QueryAnrRateMetricSetResponse,
            ) -> GooglePlayDeveloperReportingV1beta1QueryAnrRateMetricSetResponseHttpRequest | None: ...

        @typing.type_check_only
        class CrashrateResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1beta1CrashRateMetricSetHttpRequest: ...
            def query(
                self,
                *,
                name: str,
                body: GooglePlayDeveloperReportingV1beta1QueryCrashRateMetricSetRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1beta1QueryCrashRateMetricSetResponseHttpRequest: ...
            def query_next(
                self,
                previous_request: GooglePlayDeveloperReportingV1beta1QueryCrashRateMetricSetResponseHttpRequest,
                previous_response: GooglePlayDeveloperReportingV1beta1QueryCrashRateMetricSetResponse,
            ) -> GooglePlayDeveloperReportingV1beta1QueryCrashRateMetricSetResponseHttpRequest | None: ...

        @typing.type_check_only
        class ExcessivewakeuprateResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1beta1ExcessiveWakeupRateMetricSetHttpRequest: ...
            def query(
                self,
                *,
                name: str,
                body: GooglePlayDeveloperReportingV1beta1QueryExcessiveWakeupRateMetricSetRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1beta1QueryExcessiveWakeupRateMetricSetResponseHttpRequest: ...
            def query_next(
                self,
                previous_request: GooglePlayDeveloperReportingV1beta1QueryExcessiveWakeupRateMetricSetResponseHttpRequest,
                previous_response: GooglePlayDeveloperReportingV1beta1QueryExcessiveWakeupRateMetricSetResponse,
            ) -> GooglePlayDeveloperReportingV1beta1QueryExcessiveWakeupRateMetricSetResponseHttpRequest | None: ...

        @typing.type_check_only
        class StuckbackgroundwakelockrateResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1beta1StuckBackgroundWakelockRateMetricSetHttpRequest: ...
            def query(
                self,
                *,
                name: str,
                body: GooglePlayDeveloperReportingV1beta1QueryStuckBackgroundWakelockRateMetricSetRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1beta1QueryStuckBackgroundWakelockRateMetricSetResponseHttpRequest: ...
            def query_next(
                self,
                previous_request: GooglePlayDeveloperReportingV1beta1QueryStuckBackgroundWakelockRateMetricSetResponseHttpRequest,
                previous_response: GooglePlayDeveloperReportingV1beta1QueryStuckBackgroundWakelockRateMetricSetResponse,
            ) -> GooglePlayDeveloperReportingV1beta1QueryStuckBackgroundWakelockRateMetricSetResponseHttpRequest | None: ...

        def anrrate(self) -> AnrrateResource: ...
        def crashrate(self) -> CrashrateResource: ...
        def excessivewakeuprate(self) -> ExcessivewakeuprateResource: ...
        def stuckbackgroundwakelockrate(
            self,
        ) -> StuckbackgroundwakelockrateResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def anomalies(self) -> AnomaliesResource: ...
    def vitals(self) -> VitalsResource: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1beta1AnrRateMetricSetHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1beta1AnrRateMetricSet: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1beta1CrashRateMetricSetHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1beta1CrashRateMetricSet: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1beta1ExcessiveWakeupRateMetricSetHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1beta1ExcessiveWakeupRateMetricSet: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1beta1ListAnomaliesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1beta1ListAnomaliesResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1beta1QueryAnrRateMetricSetResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1beta1QueryAnrRateMetricSetResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1beta1QueryCrashRateMetricSetResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1beta1QueryCrashRateMetricSetResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1beta1QueryExcessiveWakeupRateMetricSetResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1beta1QueryExcessiveWakeupRateMetricSetResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1beta1QueryStuckBackgroundWakelockRateMetricSetResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1beta1QueryStuckBackgroundWakelockRateMetricSetResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1beta1StuckBackgroundWakelockRateMetricSetHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1beta1StuckBackgroundWakelockRateMetricSet: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DataflowResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class JobsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DebugResource(googleapiclient.discovery.Resource):
                def getConfig(
                    self,
                    *,
                    projectId: str,
                    jobId: str,
                    body: GetDebugConfigRequest = ...,
                    **kwargs: typing.Any
                ) -> GetDebugConfigResponseHttpRequest: ...
                def sendCapture(
                    self,
                    *,
                    projectId: str,
                    jobId: str,
                    body: SendDebugCaptureRequest = ...,
                    **kwargs: typing.Any
                ) -> SendDebugCaptureResponseHttpRequest: ...

            @typing.type_check_only
            class MessagesResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    projectId: str,
                    jobId: str,
                    endTime: str = ...,
                    location: str = ...,
                    minimumImportance: typing_extensions.Literal[
                        "JOB_MESSAGE_IMPORTANCE_UNKNOWN",
                        "JOB_MESSAGE_DEBUG",
                        "JOB_MESSAGE_DETAILED",
                        "JOB_MESSAGE_BASIC",
                        "JOB_MESSAGE_WARNING",
                        "JOB_MESSAGE_ERROR",
                    ] = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    startTime: str = ...,
                    **kwargs: typing.Any
                ) -> ListJobMessagesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListJobMessagesResponseHttpRequest,
                    previous_response: ListJobMessagesResponse,
                ) -> ListJobMessagesResponseHttpRequest | None: ...

            @typing.type_check_only
            class WorkItemsResource(googleapiclient.discovery.Resource):
                def lease(
                    self,
                    *,
                    projectId: str,
                    jobId: str,
                    body: LeaseWorkItemRequest = ...,
                    **kwargs: typing.Any
                ) -> LeaseWorkItemResponseHttpRequest: ...
                def reportStatus(
                    self,
                    *,
                    projectId: str,
                    jobId: str,
                    body: ReportWorkItemStatusRequest = ...,
                    **kwargs: typing.Any
                ) -> ReportWorkItemStatusResponseHttpRequest: ...

            def aggregated(
                self,
                *,
                projectId: str,
                filter: typing_extensions.Literal[
                    "UNKNOWN", "ALL", "TERMINATED", "ACTIVE"
                ] = ...,
                location: str = ...,
                name: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                view: typing_extensions.Literal[
                    "JOB_VIEW_UNKNOWN",
                    "JOB_VIEW_SUMMARY",
                    "JOB_VIEW_ALL",
                    "JOB_VIEW_DESCRIPTION",
                ] = ...,
                **kwargs: typing.Any
            ) -> ListJobsResponseHttpRequest: ...
            def aggregated_next(
                self,
                previous_request: ListJobsResponseHttpRequest,
                previous_response: ListJobsResponse,
            ) -> ListJobsResponseHttpRequest | None: ...
            def create(
                self,
                *,
                projectId: str,
                body: Job = ...,
                location: str = ...,
                replaceJobId: str = ...,
                view: typing_extensions.Literal[
                    "JOB_VIEW_UNKNOWN",
                    "JOB_VIEW_SUMMARY",
                    "JOB_VIEW_ALL",
                    "JOB_VIEW_DESCRIPTION",
                ] = ...,
                **kwargs: typing.Any
            ) -> JobHttpRequest: ...
            def get(
                self,
                *,
                projectId: str,
                jobId: str,
                location: str = ...,
                view: typing_extensions.Literal[
                    "JOB_VIEW_UNKNOWN",
                    "JOB_VIEW_SUMMARY",
                    "JOB_VIEW_ALL",
                    "JOB_VIEW_DESCRIPTION",
                ] = ...,
                **kwargs: typing.Any
            ) -> JobHttpRequest: ...
            def getMetrics(
                self,
                *,
                projectId: str,
                jobId: str,
                location: str = ...,
                startTime: str = ...,
                **kwargs: typing.Any
            ) -> JobMetricsHttpRequest: ...
            def list(
                self,
                *,
                projectId: str,
                filter: typing_extensions.Literal[
                    "UNKNOWN", "ALL", "TERMINATED", "ACTIVE"
                ] = ...,
                location: str = ...,
                name: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                view: typing_extensions.Literal[
                    "JOB_VIEW_UNKNOWN",
                    "JOB_VIEW_SUMMARY",
                    "JOB_VIEW_ALL",
                    "JOB_VIEW_DESCRIPTION",
                ] = ...,
                **kwargs: typing.Any
            ) -> ListJobsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListJobsResponseHttpRequest,
                previous_response: ListJobsResponse,
            ) -> ListJobsResponseHttpRequest | None: ...
            def snapshot(
                self,
                *,
                projectId: str,
                jobId: str,
                body: SnapshotJobRequest = ...,
                **kwargs: typing.Any
            ) -> SnapshotHttpRequest: ...
            def update(
                self,
                *,
                projectId: str,
                jobId: str,
                body: Job = ...,
                location: str = ...,
                **kwargs: typing.Any
            ) -> JobHttpRequest: ...
            def debug(self) -> DebugResource: ...
            def messages(self) -> MessagesResource: ...
            def workItems(self) -> WorkItemsResource: ...

        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class FlexTemplatesResource(googleapiclient.discovery.Resource):
                def launch(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    body: LaunchFlexTemplateRequest = ...,
                    **kwargs: typing.Any
                ) -> LaunchFlexTemplateResponseHttpRequest: ...

            @typing.type_check_only
            class JobsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class DebugResource(googleapiclient.discovery.Resource):
                    def getConfig(
                        self,
                        *,
                        projectId: str,
                        location: str,
                        jobId: str,
                        body: GetDebugConfigRequest = ...,
                        **kwargs: typing.Any
                    ) -> GetDebugConfigResponseHttpRequest: ...
                    def sendCapture(
                        self,
                        *,
                        projectId: str,
                        location: str,
                        jobId: str,
                        body: SendDebugCaptureRequest = ...,
                        **kwargs: typing.Any
                    ) -> SendDebugCaptureResponseHttpRequest: ...

                @typing.type_check_only
                class MessagesResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        projectId: str,
                        location: str,
                        jobId: str,
                        endTime: str = ...,
                        minimumImportance: typing_extensions.Literal[
                            "JOB_MESSAGE_IMPORTANCE_UNKNOWN",
                            "JOB_MESSAGE_DEBUG",
                            "JOB_MESSAGE_DETAILED",
                            "JOB_MESSAGE_BASIC",
                            "JOB_MESSAGE_WARNING",
                            "JOB_MESSAGE_ERROR",
                        ] = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        startTime: str = ...,
                        **kwargs: typing.Any
                    ) -> ListJobMessagesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListJobMessagesResponseHttpRequest,
                        previous_response: ListJobMessagesResponse,
                    ) -> ListJobMessagesResponseHttpRequest | None: ...

                @typing.type_check_only
                class SnapshotsResource(googleapiclient.discovery.Resource):
                    def list(
                        self,
                        *,
                        projectId: str,
                        location: str,
                        jobId: str,
                        **kwargs: typing.Any
                    ) -> ListSnapshotsResponseHttpRequest: ...

                @typing.type_check_only
                class StagesResource(googleapiclient.discovery.Resource):
                    def getExecutionDetails(
                        self,
                        *,
                        projectId: str,
                        location: str,
                        jobId: str,
                        stageId: str,
                        endTime: str = ...,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        startTime: str = ...,
                        **kwargs: typing.Any
                    ) -> StageExecutionDetailsHttpRequest: ...
                    def getExecutionDetails_next(
                        self,
                        previous_request: StageExecutionDetailsHttpRequest,
                        previous_response: StageExecutionDetails,
                    ) -> StageExecutionDetailsHttpRequest | None: ...

                @typing.type_check_only
                class WorkItemsResource(googleapiclient.discovery.Resource):
                    def lease(
                        self,
                        *,
                        projectId: str,
                        location: str,
                        jobId: str,
                        body: LeaseWorkItemRequest = ...,
                        **kwargs: typing.Any
                    ) -> LeaseWorkItemResponseHttpRequest: ...
                    def reportStatus(
                        self,
                        *,
                        projectId: str,
                        location: str,
                        jobId: str,
                        body: ReportWorkItemStatusRequest = ...,
                        **kwargs: typing.Any
                    ) -> ReportWorkItemStatusResponseHttpRequest: ...

                def create(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    body: Job = ...,
                    replaceJobId: str = ...,
                    view: typing_extensions.Literal[
                        "JOB_VIEW_UNKNOWN",
                        "JOB_VIEW_SUMMARY",
                        "JOB_VIEW_ALL",
                        "JOB_VIEW_DESCRIPTION",
                    ] = ...,
                    **kwargs: typing.Any
                ) -> JobHttpRequest: ...
                def get(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    jobId: str,
                    view: typing_extensions.Literal[
                        "JOB_VIEW_UNKNOWN",
                        "JOB_VIEW_SUMMARY",
                        "JOB_VIEW_ALL",
                        "JOB_VIEW_DESCRIPTION",
                    ] = ...,
                    **kwargs: typing.Any
                ) -> JobHttpRequest: ...
                def getExecutionDetails(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    jobId: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> JobExecutionDetailsHttpRequest: ...
                def getExecutionDetails_next(
                    self,
                    previous_request: JobExecutionDetailsHttpRequest,
                    previous_response: JobExecutionDetails,
                ) -> JobExecutionDetailsHttpRequest | None: ...
                def getMetrics(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    jobId: str,
                    startTime: str = ...,
                    **kwargs: typing.Any
                ) -> JobMetricsHttpRequest: ...
                def list(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    filter: typing_extensions.Literal[
                        "UNKNOWN", "ALL", "TERMINATED", "ACTIVE"
                    ] = ...,
                    name: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    view: typing_extensions.Literal[
                        "JOB_VIEW_UNKNOWN",
                        "JOB_VIEW_SUMMARY",
                        "JOB_VIEW_ALL",
                        "JOB_VIEW_DESCRIPTION",
                    ] = ...,
                    **kwargs: typing.Any
                ) -> ListJobsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListJobsResponseHttpRequest,
                    previous_response: ListJobsResponse,
                ) -> ListJobsResponseHttpRequest | None: ...
                def snapshot(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    jobId: str,
                    body: SnapshotJobRequest = ...,
                    **kwargs: typing.Any
                ) -> SnapshotHttpRequest: ...
                def update(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    jobId: str,
                    body: Job = ...,
                    **kwargs: typing.Any
                ) -> JobHttpRequest: ...
                def debug(self) -> DebugResource: ...
                def messages(self) -> MessagesResource: ...
                def snapshots(self) -> SnapshotsResource: ...
                def stages(self) -> StagesResource: ...
                def workItems(self) -> WorkItemsResource: ...

            @typing.type_check_only
            class SnapshotsResource(googleapiclient.discovery.Resource):
                def delete(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    snapshotId: str,
                    **kwargs: typing.Any
                ) -> DeleteSnapshotResponseHttpRequest: ...
                def get(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    snapshotId: str,
                    **kwargs: typing.Any
                ) -> SnapshotHttpRequest: ...
                def list(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    jobId: str = ...,
                    **kwargs: typing.Any
                ) -> ListSnapshotsResponseHttpRequest: ...

            @typing.type_check_only
            class SqlResource(googleapiclient.discovery.Resource):
                def validate(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    query: str = ...,
                    **kwargs: typing.Any
                ) -> ValidateResponseHttpRequest: ...

            @typing.type_check_only
            class TemplatesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    body: CreateJobFromTemplateRequest = ...,
                    **kwargs: typing.Any
                ) -> JobHttpRequest: ...
                def get(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    gcsPath: str = ...,
                    view: typing_extensions.Literal["METADATA_ONLY"] = ...,
                    **kwargs: typing.Any
                ) -> GetTemplateResponseHttpRequest: ...
                def launch(
                    self,
                    *,
                    projectId: str,
                    location: str,
                    body: LaunchTemplateParameters = ...,
                    dynamicTemplate_gcsPath: str = ...,
                    dynamicTemplate_stagingLocation: str = ...,
                    gcsPath: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> LaunchTemplateResponseHttpRequest: ...

            def workerMessages(
                self,
                *,
                projectId: str,
                location: str,
                body: SendWorkerMessagesRequest = ...,
                **kwargs: typing.Any
            ) -> SendWorkerMessagesResponseHttpRequest: ...
            def flexTemplates(self) -> FlexTemplatesResource: ...
            def jobs(self) -> JobsResource: ...
            def snapshots(self) -> SnapshotsResource: ...
            def sql(self) -> SqlResource: ...
            def templates(self) -> TemplatesResource: ...

        @typing.type_check_only
        class SnapshotsResource(googleapiclient.discovery.Resource):
            def get(
                self,
                *,
                projectId: str,
                snapshotId: str,
                location: str = ...,
                **kwargs: typing.Any
            ) -> SnapshotHttpRequest: ...
            def list(
                self,
                *,
                projectId: str,
                jobId: str = ...,
                location: str = ...,
                **kwargs: typing.Any
            ) -> ListSnapshotsResponseHttpRequest: ...

        @typing.type_check_only
        class TemplatesResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                projectId: str,
                body: CreateJobFromTemplateRequest = ...,
                **kwargs: typing.Any
            ) -> JobHttpRequest: ...
            def get(
                self,
                *,
                projectId: str,
                gcsPath: str = ...,
                location: str = ...,
                view: typing_extensions.Literal["METADATA_ONLY"] = ...,
                **kwargs: typing.Any
            ) -> GetTemplateResponseHttpRequest: ...
            def launch(
                self,
                *,
                projectId: str,
                body: LaunchTemplateParameters = ...,
                dynamicTemplate_gcsPath: str = ...,
                dynamicTemplate_stagingLocation: str = ...,
                gcsPath: str = ...,
                location: str = ...,
                validateOnly: bool = ...,
                **kwargs: typing.Any
            ) -> LaunchTemplateResponseHttpRequest: ...

        def deleteSnapshots(
            self,
            *,
            projectId: str,
            location: str = ...,
            snapshotId: str = ...,
            **kwargs: typing.Any
        ) -> DeleteSnapshotResponseHttpRequest: ...
        def workerMessages(
            self,
            *,
            projectId: str,
            body: SendWorkerMessagesRequest = ...,
            **kwargs: typing.Any
        ) -> SendWorkerMessagesResponseHttpRequest: ...
        def jobs(self) -> JobsResource: ...
        def locations(self) -> LocationsResource: ...
        def snapshots(self) -> SnapshotsResource: ...
        def templates(self) -> TemplatesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class DeleteSnapshotResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DeleteSnapshotResponse: ...

@typing.type_check_only
class GetDebugConfigResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetDebugConfigResponse: ...

@typing.type_check_only
class GetTemplateResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetTemplateResponse: ...

@typing.type_check_only
class JobHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Job: ...

@typing.type_check_only
class JobExecutionDetailsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> JobExecutionDetails: ...

@typing.type_check_only
class JobMetricsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> JobMetrics: ...

@typing.type_check_only
class LaunchFlexTemplateResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LaunchFlexTemplateResponse: ...

@typing.type_check_only
class LaunchTemplateResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LaunchTemplateResponse: ...

@typing.type_check_only
class LeaseWorkItemResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LeaseWorkItemResponse: ...

@typing.type_check_only
class ListJobMessagesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListJobMessagesResponse: ...

@typing.type_check_only
class ListJobsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListJobsResponse: ...

@typing.type_check_only
class ListSnapshotsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSnapshotsResponse: ...

@typing.type_check_only
class ReportWorkItemStatusResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReportWorkItemStatusResponse: ...

@typing.type_check_only
class SendDebugCaptureResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SendDebugCaptureResponse: ...

@typing.type_check_only
class SendWorkerMessagesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SendWorkerMessagesResponse: ...

@typing.type_check_only
class SnapshotHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Snapshot: ...

@typing.type_check_only
class StageExecutionDetailsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> StageExecutionDetails: ...

@typing.type_check_only
class ValidateResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ValidateResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Area(typing_extensions.TypedDict, total=False):
    basemapZOrder: BasemapZOrder
    hasExternalEdges: bool
    internalEdges: _list[int]
    loopBreaks: _list[int]
    triangleIndices: _list[int]
    type: typing_extensions.Literal[
        "TRIANGLE_FAN", "INDEXED_TRIANGLES", "TRIANGLE_STRIP"
    ]
    vertexOffsets: Vertex2DList
    zOrder: int

@typing.type_check_only
class BasemapZOrder(typing_extensions.TypedDict, total=False):
    zGrade: int
    zPlane: int
    zWithinGrade: int

@typing.type_check_only
class ExtrudedArea(typing_extensions.TypedDict, total=False):
    area: Area
    maxZ: int
    minZ: int

@typing.type_check_only
class Feature(typing_extensions.TypedDict, total=False):
    displayName: str
    geometry: Geometry
    placeId: str
    relations: _list[Relation]
    segmentInfo: SegmentInfo
    type: typing_extensions.Literal[
        "FEATURE_TYPE_UNSPECIFIED",
        "STRUCTURE",
        "BAR",
        "BANK",
        "LODGING",
        "CAFE",
        "RESTAURANT",
        "EVENT_VENUE",
        "TOURIST_DESTINATION",
        "SHOPPING",
        "SCHOOL",
        "SEGMENT",
        "ROAD",
        "LOCAL_ROAD",
        "ARTERIAL_ROAD",
        "HIGHWAY",
        "CONTROLLED_ACCESS_HIGHWAY",
        "FOOTPATH",
        "RAIL",
        "FERRY",
        "REGION",
        "PARK",
        "BEACH",
        "FOREST",
        "POLITICAL",
        "ADMINISTRATIVE_AREA1",
        "LOCALITY",
        "SUBLOCALITY",
        "WATER",
    ]

@typing.type_check_only
class FeatureTile(typing_extensions.TypedDict, total=False):
    coordinates: TileCoordinates
    features: _list[Feature]
    name: str
    providers: _list[ProviderInfo]
    status: typing_extensions.Literal["STATUS_OK", "STATUS_OK_DATA_UNCHANGED"]
    versionId: str

@typing.type_check_only
class FirstDerivativeElevationGrid(typing_extensions.TypedDict, total=False):
    altitudeMultiplier: float
    rows: _list[Row]

@typing.type_check_only
class Geometry(typing_extensions.TypedDict, total=False):
    areas: _list[Area]
    extrudedAreas: _list[ExtrudedArea]
    lines: _list[Line]
    modeledVolumes: _list[ModeledVolume]

@typing.type_check_only
class Line(typing_extensions.TypedDict, total=False):
    basemapZOrder: BasemapZOrder
    vertexOffsets: Vertex2DList
    zOrder: int

@typing.type_check_only
class ModeledVolume(typing_extensions.TypedDict, total=False):
    strips: _list[TriangleStrip]
    vertexOffsets: Vertex3DList

@typing.type_check_only
class ProviderInfo(typing_extensions.TypedDict, total=False):
    description: str

@typing.type_check_only
class Relation(typing_extensions.TypedDict, total=False):
    relatedFeatureIndex: int
    relationType: typing_extensions.Literal[
        "RELATION_TYPE_UNSPECIFIED", "OCCUPIES", "PRIMARILY_OCCUPIED_BY"
    ]

@typing.type_check_only
class RoadInfo(typing_extensions.TypedDict, total=False):
    isPrivate: bool

@typing.type_check_only
class Row(typing_extensions.TypedDict, total=False):
    altitudeDiffs: _list[int]

@typing.type_check_only
class SecondDerivativeElevationGrid(typing_extensions.TypedDict, total=False):
    altitudeMultiplier: float
    columnCount: int
    encodedData: str
    rowCount: int

@typing.type_check_only
class SegmentInfo(typing_extensions.TypedDict, total=False):
    roadInfo: RoadInfo

@typing.type_check_only
class TerrainTile(typing_extensions.TypedDict, total=False):
    coordinates: TileCoordinates
    firstDerivative: FirstDerivativeElevationGrid
    name: str
    secondDerivative: SecondDerivativeElevationGrid

@typing.type_check_only
class TileCoordinates(typing_extensions.TypedDict, total=False):
    x: int
    y: int
    zoom: int

@typing.type_check_only
class TriangleStrip(typing_extensions.TypedDict, total=False):
    vertexIndices: _list[int]

@typing.type_check_only
class Vertex2DList(typing_extensions.TypedDict, total=False):
    xOffsets: _list[int]
    yOffsets: _list[int]

@typing.type_check_only
class Vertex3DList(typing_extensions.TypedDict, total=False):
    xOffsets: _list[int]
    yOffsets: _list[int]
    zOffsets: _list[int]



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudResourceManagerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class FoldersResource(googleapiclient.discovery.Resource):
        def create(
            self, *, body: Folder = ..., parent: str = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def delete(self, *, name: str, **kwargs: typing.Any) -> FolderHttpRequest: ...
        def get(self, *, name: str, **kwargs: typing.Any) -> FolderHttpRequest: ...
        def getIamPolicy(
            self,
            *,
            resource: str,
            body: GetIamPolicyRequest = ...,
            **kwargs: typing.Any
        ) -> PolicyHttpRequest: ...
        def list(
            self,
            *,
            pageSize: int = ...,
            pageToken: str = ...,
            parent: str = ...,
            showDeleted: bool = ...,
            **kwargs: typing.Any
        ) -> ListFoldersResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListFoldersResponseHttpRequest,
            previous_response: ListFoldersResponse,
        ) -> ListFoldersResponseHttpRequest | None: ...
        def move(
            self, *, name: str, body: MoveFolderRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def patch(
            self,
            *,
            name: str,
            body: Folder = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> FolderHttpRequest: ...
        def search(
            self, *, body: SearchFoldersRequest = ..., **kwargs: typing.Any
        ) -> SearchFoldersResponseHttpRequest: ...
        def search_next(
            self,
            previous_request: SearchFoldersResponseHttpRequest,
            previous_response: SearchFoldersResponse,
        ) -> SearchFoldersResponseHttpRequest | None: ...
        def setIamPolicy(
            self,
            *,
            resource: str,
            body: SetIamPolicyRequest = ...,
            **kwargs: typing.Any
        ) -> PolicyHttpRequest: ...
        def testIamPermissions(
            self,
            *,
            resource: str,
            body: TestIamPermissionsRequest = ...,
            **kwargs: typing.Any
        ) -> TestIamPermissionsResponseHttpRequest: ...
        def undelete(
            self, *, name: str, body: UndeleteFolderRequest = ..., **kwargs: typing.Any
        ) -> FolderHttpRequest: ...

    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def folders(self) -> FoldersResource: ...
    def operations(self) -> OperationsResource: ...

@typing.type_check_only
class FolderHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Folder: ...

@typing.type_check_only
class ListFoldersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFoldersResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Policy: ...

@typing.type_check_only
class SearchFoldersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchFoldersResponse: ...

@typing.type_check_only
class TestIamPermissionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TestIamPermissionsResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class BigQueryReservationResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            @typing.type_check_only
            class ReservationGrantsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: ReservationGrant = ...,
                    **kwargs: typing.Any
                ) -> ReservationGrantHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListReservationGrantsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListReservationGrantsResponseHttpRequest,
                    previous_response: ListReservationGrantsResponse,
                ) -> ListReservationGrantsResponseHttpRequest | None: ...

            @typing.type_check_only
            class ReservationsResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class SlotPoolsResource(googleapiclient.discovery.Resource):
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> SlotPoolHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListSlotPoolsResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListSlotPoolsResponseHttpRequest,
                        previous_response: ListSlotPoolsResponse,
                    ) -> ListSlotPoolsResponseHttpRequest | None: ...

                def create(
                    self,
                    *,
                    parent: str,
                    body: Reservation = ...,
                    reservationId: str = ...,
                    **kwargs: typing.Any
                ) -> ReservationHttpRequest: ...
                def createReservation(
                    self,
                    *,
                    parent: str,
                    body: Reservation = ...,
                    reservationId: str = ...,
                    **kwargs: typing.Any
                ) -> ReservationHttpRequest: ...
                def delete(
                    self, *, name: str, force: bool = ..., **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ReservationHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListReservationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListReservationsResponseHttpRequest,
                    previous_response: ListReservationsResponse,
                ) -> ListReservationsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Reservation = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> ReservationHttpRequest: ...
                def slotPools(self) -> SlotPoolsResource: ...

            def searchReservationGrants(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                query: str = ...,
                **kwargs: typing.Any
            ) -> SearchReservationGrantsResponseHttpRequest: ...
            def searchReservationGrants_next(
                self,
                previous_request: SearchReservationGrantsResponseHttpRequest,
                previous_response: SearchReservationGrantsResponse,
            ) -> SearchReservationGrantsResponseHttpRequest | None: ...
            def operations(self) -> OperationsResource: ...
            def reservationGrants(self) -> ReservationGrantsResource: ...
            def reservations(self) -> ReservationsResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListReservationGrantsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListReservationGrantsResponse: ...

@typing.type_check_only
class ListReservationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListReservationsResponse: ...

@typing.type_check_only
class ListSlotPoolsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSlotPoolsResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class ReservationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Reservation: ...

@typing.type_check_only
class ReservationGrantHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReservationGrant: ...

@typing.type_check_only
class SearchReservationGrantsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchReservationGrantsResponse: ...

@typing.type_check_only
class SlotPoolHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SlotPool: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    ignoreChildExemptions: bool
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class AuthorizationLoggingOptions(typing_extensions.TypedDict, total=False):
    permissionType: typing_extensions.Literal[
        "PERMISSION_TYPE_UNSPECIFIED",
        "ADMIN_READ",
        "ADMIN_WRITE",
        "DATA_READ",
        "DATA_WRITE",
    ]

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    bindingId: str
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CloudAuditOptions(typing_extensions.TypedDict, total=False):
    authorizationLoggingOptions: AuthorizationLoggingOptions
    logName: typing_extensions.Literal[
        "UNSPECIFIED_LOG_NAME", "ADMIN_ACTIVITY", "DATA_ACCESS"
    ]

@typing.type_check_only
class Condition(typing_extensions.TypedDict, total=False):
    iam: typing_extensions.Literal[
        "NO_ATTR",
        "AUTHORITY",
        "ATTRIBUTION",
        "SECURITY_REALM",
        "APPROVER",
        "JUSTIFICATION_TYPE",
        "CREDENTIALS_TYPE",
        "CREDS_ASSERTION",
    ]
    op: typing_extensions.Literal[
        "NO_OP", "EQUALS", "NOT_EQUALS", "IN", "NOT_IN", "DISCHARGED"
    ]
    svc: str
    sys: typing_extensions.Literal["NO_ATTR", "REGION", "SERVICE", "NAME", "IP"]
    values: _list[str]

@typing.type_check_only
class CounterOptions(typing_extensions.TypedDict, total=False):
    customFields: _list[CustomField]
    field: str
    metric: str

@typing.type_check_only
class CustomField(typing_extensions.TypedDict, total=False):
    name: str
    value: str

@typing.type_check_only
class DataAccessOptions(typing_extensions.TypedDict, total=False):
    logMode: typing_extensions.Literal["LOG_MODE_UNSPECIFIED", "LOG_FAIL_CLOSED"]

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class LogConfig(typing_extensions.TypedDict, total=False):
    cloudAudit: CloudAuditOptions
    counter: CounterOptions
    dataAccess: DataAccessOptions

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    rules: _list[Rule]
    version: int

AlternativeRule = typing_extensions.TypedDict(
    "AlternativeRule",
    {
        "action": typing_extensions.Literal[
            "NO_ACTION", "ALLOW", "ALLOW_WITH_LOG", "DENY", "DENY_WITH_LOG", "LOG"
        ],
        "conditions": _list[Condition],
        "description": str,
        "in": _list[str],
        "logConfig": _list[LogConfig],
        "notIn": _list[str],
        "permissions": _list[str],
    },
    total=False,
)

@typing.type_check_only
class Rule(AlternativeRule): ...

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]
